@@ -55,20 +55,6 @@ __PACKAGE__->belongs_to(parent_value =>
 
 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-OpusVL::Preferences::Schema::Result::CustomDataUniqueValues
-
-=head1 VERSION
-
-version 0.28
-
 =head1 DESCRIPTION
 
 I thought this was obvious until I realised it has a 'name' column and now I
@@ -90,21 +76,11 @@ have no idea what it does.
 
 =head2 parent_value
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013 OpusVL.
 
 This software is licensed according to the "IP Assignment Schedule" provided with the development project.
 
-=head1 AUTHOR
-
-OpusVL - www.opusvl.com
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by OpusVL - www.opusvl.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
