@@ -9,6 +9,9 @@ use namespace::autoclean;
 
 extends 'DBIx::Class::Core';
 
+__PACKAGE__->table("prf_owners");
+
+__PACKAGE__->add_columns
 (
 	prf_owner_id =>
 	{
@@ -62,19 +65,6 @@ __PACKAGE__->has_many
 
 return 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-OpusVL::Preferences::Schema::Result::PrfOwner
-
-=head1 VERSION
-
-version 0.28
 
 =head1 DESCRIPTION
 
@@ -98,21 +88,11 @@ object in the same place.
 
 =head2 prf_owner_type_id
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 OpusVL.
 
 This software is licensed according to the "IP Assignment Schedule" provided with the development project.
 
-=head1 AUTHOR
-
-OpusVL - www.opusvl.com
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by OpusVL - www.opusvl.com.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
